@@ -11,6 +11,8 @@
 
 QT_BEGIN_NAMESPACE
 
+using namespace Qt::Literals::StringLiterals;
+
 /*!
     \class QOpcUaClient
     \inmodule QtOpcUa
@@ -102,6 +104,18 @@ QT_BEGIN_NAMESPACE
            An unknown error occurred.
     \value UnsupportedAuthenticationInformation
            The given type or data of authentication information is not supported.
+    \value InvalidAuthenticationInformation
+           The provided authentication information is invalid
+    \value InvalidEndpointDescription
+           The endpoint description is invalid, e. g. because of an empty URL or no user identity tokens.
+    \value NoMatchingUserIdentityTokenFound
+           The selected endpoint doesn't support the requested token type or supported policies.
+    \value UnsupportedSecurityPolicy
+           The security policy for the endpoint is not supported.
+    \value InvalidPki
+           A certificate or key of the PKI could not be loaded or is invalid
+    \value CertificateUntrusted
+           The server certificate is untrusted
 */
 
 /*!
@@ -558,7 +572,7 @@ QString QOpcUaClient::resolveExpandedNodeId(const QOpcUaExpandedNodeId &expanded
             return QString();
         }
 
-        QStringList splitId = expandedNodeId.nodeId().split(QLatin1String(";"));
+        QStringList splitId = expandedNodeId.nodeId().split(';'_L1);
         if (splitId.size() != 2) {
             qCWarning(QT_OPCUA) << "Failed to split node id" << expandedNodeId.nodeId();
             if (ok)
@@ -568,7 +582,7 @@ QString QOpcUaClient::resolveExpandedNodeId(const QOpcUaExpandedNodeId &expanded
 
         if (ok)
             *ok = true;
-        return QStringLiteral("ns=%1;").arg(index).append(splitId.at(1));
+        return u"ns=%1;"_s.arg(index).append(splitId.at(1));
     }
 }
 
